@@ -1,15 +1,11 @@
 #######################################################################
-# $Id: TriangularNumber.pm,v 1.22 2010-11-30 20:29:19 dpchrist Exp $
+# $Id: TriangularNumber.pm,v 1.23 2010-12-03 05:13:53 dpchrist Exp $
 #######################################################################
 # package:
 #----------------------------------------------------------------------
 
 package Dpchrist::TriangularNumber;
 
-#######################################################################
-# uses/ requires:
-#----------------------------------------------------------------------
-
 use strict;
 use warnings;
 
@@ -19,9 +15,6 @@ use constant EPSILON		=> 1.0E-06;
 use Dpchrist::Debug		qw( :all );
 
 require Exporter;
-#######################################################################
-# global variables:
-#----------------------------------------------------------------------
 
 our @ISA = qw(Exporter);
 
@@ -35,7 +28,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw();
 
-our $VERSION = sprintf("%d.%03d", q$Revision: 1.22 $ =~ /(\d+)/g);
+our $VERSION = sprintf("%d.%03d", q$Revision: 1.23 $ =~ /(\d+)/g);
 
 #######################################################################
 
@@ -72,7 +65,7 @@ Output:
 
 =head1 DESCRIPTION
 
-This documentation describes module revision $Revision: 1.22 $.
+This documentation describes module revision $Revision: 1.23 $.
 
 
 This is alpha test level software
@@ -216,9 +209,7 @@ None by default.
 
 All of the subroutines may be imported by using the ':all' tag:
 
-    use Dpchrist::CGI		qw( :all ); 
-
-See 'perldoc Export' for everything in between.
+    use Dpchrist::TriangularNumber	qw( :all ); 
 
 
 =head1 INSTALLATION
@@ -238,13 +229,6 @@ Complete:
 
     $ cpan Bundle::Dpchrist
 
-The following warning may be safely ignored:
-
-    Can't locate Dpchrist/Module/MakefilePL.pm in @INC (@INC contains: /
-    etc/perl /usr/local/lib/perl/5.10.0 /usr/local/share/perl/5.10.0 /us
-    r/lib/perl5 /usr/share/perl5 /usr/lib/perl/5.10 /usr/share/perl/5.10
-    /usr/local/lib/site_perl .) at Makefile.PL line 22.
-
 
 =head2 PREREQUISITES
 
